]> sigrok.org Git - libsigrok.git/blobdiff - std.c
contrib/z60_libsigrok.rules: Add entry for the Saleae Logic16.
[libsigrok.git] / std.c
diff --git a/std.c b/std.c
index 059bf759013ef5274af32aa6c797a913c55b3da5..22123fc5d743dc527ca31af3e3cdca549cf8b31d 100644 (file)
--- a/std.c
+++ b/std.c
@@ -37,8 +37,8 @@
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
  *         SR_ERR_MALLOC upon memory allocation errors.
  */
-SR_PRIV int std_hw_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
-                       const char *prefix)
+SR_PRIV int std_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
+                    const char *prefix)
 {
        struct drv_context *drvc;
 
@@ -117,10 +117,12 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  * @param prefix A driver-specific prefix string used for log messages.
  *               Must not be NULL. An empty string is allowed.
  *
* @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
*         SR_ERR upon other errors.
  */
-SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
+SR_PRIV int std_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
                        void *cb_data, dev_close_t dev_close_fn,
                        struct sr_serial_dev_inst *serial, const char *prefix)
 {
@@ -134,7 +136,7 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
 
        if (sdi->status != SR_ST_ACTIVE) {
                sr_err("%sDevice inactive, can't stop acquisition.", prefix);
-               return SR_ERR;
+               return SR_ERR_DEV_CLOSED;
        }
 
        sr_dbg("%sStopping acquisition.", prefix);
@@ -117,10 +117,12 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  *               Must not be NULL. An empty string is allowed.
  *
- * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
- *         SR_ERR upon other errors.
+ * @retval SR_OK Success.
+ * @retval SR_ERR_ARG Invalid arguments.
+ * @retval SR_ERR_DEV_CLOSED Device is closed.
+ * @retval SR_ERR Other errors.
  */